@@ -1,24 +1,23 @@
 #!/bin/bash
 # PHP-5.3	(http://www.php.net)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-28
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-09-04
 # require:
-HTTPD_VER=2.2.19
+HTTPD_VER=2.2.20
 HTTPD=httpd-$HTTPD_VER
 #	postgresql-8.4.x
 #	re2c-0.13.5
 #PHP
-VERSION=5.3.6
-#VERSION=5.2.7RC4
+VERSION=5.3.8
 REL=P2
 
 #SUHOSIN
 # ex. http://download.suhosin.org/suhosin-0.9.29.tgz
 SUHOSIN=suhosin-0.9.32.1
-# ex. http://download.suhosin.org/suhosin-patch-5.2.x-0.9.x.patch.gz
+# ex. http://download.suhosin.org/suhosin-patch-5.3.x-0.9.x.patch.gz
+#PAT_VER=0.9.10
 PAT_VER=
-#PAT_VER=0.9.8
-DOC_ONLY=-1
+DOC_ONLY=
 #DOC_ONLY=1	# 1: document package only
 BIN_ONLY=0
 BIN_ONLY=1	# 1: php binary package only
@@ -97,7 +96,7 @@ mkdir -p $WORK
 export LANG=C
 export LC_ALL=C
 export CFLAGS="-O2 -march=$CPU"
-export PATH=$PATH:/usr/X11R7/bin:/$PREFIX/bin
+export PATH=/$PREFIX/bin:$PATH:/usr/X11R7/bin
 
 
 if [ "$DOC_ONLY" != "1" ]; then
@@ -142,12 +141,14 @@ make
 mv /opt/httpd/conf/httpd.conf /opt/httpd/conf/httpd.conf.orig
 mv /opt/httpd/modules/libphp5.so /opt/httpd/modules/libphp5.so.orig
 make install
+
 mv /opt/httpd/conf/httpd.conf.orig /opt/httpd/conf/httpd.conf
 
 mkdir -p $WORK/opt/htdocs
 
 export PATH=/$PREFIX/bin:$PATH
 
+rm -f /root/.pearrc
 rm -rf /$PREFIX/lib/php/.channels/
 rm -rf /$PREFIX/lib/php/.registry/
 pear config-set php_ini $CUSTOM_DIR/php.ini 
@@ -187,7 +188,7 @@ ZTS=`sh ./scripts/php-config --extension-dir`
 
  cd ext/gd
    phpize
-   LIBS=" -lz -lm " ./configure --enable-gd-native-ttf --enable-gd-jis-conv --with-freetype-dir=/usr/X11R7 --with-xpm-dir=/usr/X11R7 --with-jpeg-dir=/usr --with-png-dir=/usr  --with-zlib-dir=/usr
+   LIBS=" -lz -lm " ./configure --enable-gd-native-ttf --enable-gd-jis-conv --with-freetype-dir=/usr/X11R7 --with-xpm-dir=/usr/X11R7 --with-jpeg-dir=/usr --with-png-dir=/usr  --with-zlib-dir=/usr --with-gd=/usr
 
    make; make install
    cat >> ../extpkg.lis<<__EOFgd
